@@ -12,7 +12,6 @@ fn main() -> std::io::Result<()> {
         .arg_required_else_help(true)
         .subcommand(cmd_linkr::circos::make_subcommand())
         .subcommand(cmd_linkr::sort::make_subcommand())
-        .subcommand(cmd_linkr::merge::make_subcommand())
         .subcommand(cmd_linkr::filter::make_subcommand())
         .subcommand(cmd_linkr::clean::make_subcommand())
         .subcommand(cmd_linkr::connect::make_subcommand());
@@ -21,7 +20,6 @@ fn main() -> std::io::Result<()> {
     match app.get_matches().subcommand() {
         Some(("circos", sub_matches)) => cmd_linkr::circos::execute(sub_matches),
         Some(("sort", sub_matches)) => cmd_linkr::sort::execute(sub_matches),
-        Some(("merge", sub_matches)) => cmd_linkr::merge::execute(sub_matches),
         Some(("filter", sub_matches)) => cmd_linkr::filter::execute(sub_matches),
         Some(("clean", sub_matches)) => cmd_linkr::clean::execute(sub_matches),
         Some(("connect", sub_matches)) => cmd_linkr::connect::execute(sub_matches),
